@@ -321,6 +321,9 @@ class DataTable(hg.TABLE):
                 Link(
                     href=ModelHref(model, "add"),
                     label=_("Add %s") % pretty_modelname(model),
+                    permissions=[
+                        f"{model._meta.app_label}.add_{model._meta.model_name}"
+                    ],
                 ),
                 icon=Icon("add", size=20),
             )
@@ -406,7 +409,11 @@ class DataTable(hg.TABLE):
             title,
             helper_text=hg.format(
                 "{} {}",
-                hg.F(lambda c: len(hg.resolve_lazy(queryset, c))),
+                hg.F(
+                    lambda c: len(hg.resolve_lazy(queryset, c))
+                    if pagination_config is None
+                    else hg.getattr_lazy(pagination_config.paginator, "count")
+                ),
                 model._meta.verbose_name_plural,
             ),
             primary_button=primary_button,
